@@ -11,11 +11,7 @@
 #include <QSharedPointer>
 #include <QVariantHash>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-namespace Grantlee
-#else
 namespace KTextTemplate
-#endif
 {
 class Engine;
 class FileSystemTemplateLoader;
@@ -37,26 +33,16 @@ public:
     void setTemplatePath(const QString &path);
     void setPluginPath(const QString &path);
 
-    Q_REQUIRED_RESULT QString render(const QString &templateName, const QVariantHash &data) const;
+    [[nodiscard]] QString render(const QString &templateName, const QVariantHash &data) const;
 
 private:
     Q_DISABLE_COPY(GrantleeTemplateManager)
     GrantleeTemplateManager();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QString errorTemplate(const QString &reason, const QString &origTemplateName, const Grantlee::Template &failedTemplate) const;
-    Grantlee::Context createContext(const QVariantHash &hash = QVariantHash()) const;
-#else
     QString errorTemplate(const QString &reason, const QString &origTemplateName, const KTextTemplate::Template &failedTemplate) const;
     KTextTemplate::Context createContext(const QVariantHash &hash = QVariantHash()) const;
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Grantlee::Engine *const mEngine;
-    QSharedPointer<Grantlee::FileSystemTemplateLoader> mLoader;
-#else
     KTextTemplate::Engine *const mEngine;
     QSharedPointer<KTextTemplate::FileSystemTemplateLoader> mLoader;
 
-#endif
     QSharedPointer<GrantleeKi18nLocalizer> mLocalizer;
 
     static GrantleeTemplateManager *sInstance;
