@@ -16,19 +16,21 @@
   @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
   @author Allen Winter \<allen@kdab.com\>
 */
-#ifndef KCALUTILS_INCIDENCEFORMATTER_H
-#define KCALUTILS_INCIDENCEFORMATTER_H
+#pragma once
 
 #include "kcalutils_export.h"
 
+#include <KCalendarCore/Calendar>
 #include <KCalendarCore/Incidence>
-#include <KCalendarCore/MemoryCalendar>
 
 #include <QDate>
-class InvitationFormatterHelperPrivate;
+
+#include <memory>
 
 namespace KCalUtils
 {
+class InvitationFormatterHelperPrivate;
+
 /**
  * @brief The InvitationFormatterHelper class
  */
@@ -37,14 +39,14 @@ class KCALUTILS_EXPORT InvitationFormatterHelper
 public:
     InvitationFormatterHelper();
     virtual ~InvitationFormatterHelper();
-    Q_REQUIRED_RESULT virtual QString generateLinkURL(const QString &id);
-    Q_REQUIRED_RESULT virtual QString makeLink(const QString &id, const QString &text);
-    Q_REQUIRED_RESULT virtual KCalendarCore::Calendar::Ptr calendar() const;
+    [[nodiscard]] virtual QString generateLinkURL(const QString &id);
+    [[nodiscard]] virtual QString makeLink(const QString &id, const QString &text);
+    [[nodiscard]] virtual KCalendarCore::Calendar::Ptr calendar() const;
 
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(InvitationFormatterHelper)
-    InvitationFormatterHelperPrivate *const d;
+    std::unique_ptr<InvitationFormatterHelperPrivate> const d;
     //@endcond
 };
 
@@ -115,7 +117,7 @@ KCALUTILS_EXPORT QString mailBodyStr(const KCalendarCore::IncidenceBase::Ptr &in
 
   @since 5.23.0
 */
-KCALUTILS_EXPORT QString formatICalInvitation(const QString &invitation, const KCalendarCore::MemoryCalendar::Ptr &calendar, InvitationFormatterHelper *helper);
+KCALUTILS_EXPORT QString formatICalInvitation(const QString &invitation, const KCalendarCore::Calendar::Ptr &calendar, InvitationFormatterHelper *helper);
 
 /**
   Deliver an HTML formatted string displaying an invitation.
@@ -132,7 +134,7 @@ KCALUTILS_EXPORT QString formatICalInvitation(const QString &invitation, const K
   @since 5.23.0
 */
 KCALUTILS_EXPORT QString formatICalInvitationNoHtml(const QString &invitation,
-                                                    const KCalendarCore::MemoryCalendar::Ptr &calendar,
+                                                    const KCalendarCore::Calendar::Ptr &calendar,
                                                     InvitationFormatterHelper *helper,
                                                     const QString &sender);
 
@@ -159,7 +161,7 @@ KCALUTILS_EXPORT QStringList reminderStringList(const KCalendarCore::Incidence::
   @param shortfmt If true, display info in short format.
   @see dateToString(), dateTimeToString().
 */
-KCALUTILS_EXPORT QString timeToString(const QTime &time, bool shortfmt = true);
+KCALUTILS_EXPORT QString timeToString(QTime time, bool shortfmt = true);
 
 /**
   Build a QString date representation of a QDate object.
@@ -168,7 +170,7 @@ KCALUTILS_EXPORT QString timeToString(const QTime &time, bool shortfmt = true);
   @param shortfmt If true, display info in short format.
   @see dateToString(), dateTimeToString().
 */
-KCALUTILS_EXPORT QString dateToString(const QDate &date, bool shortfmt = true);
+KCALUTILS_EXPORT QString dateToString(QDate date, bool shortfmt = true);
 
 KCALUTILS_EXPORT QString formatStartEnd(const QDateTime &start, const QDateTime &end, bool isAllDay);
 
@@ -197,12 +199,11 @@ KCALUTILS_EXPORT QString resourceString(const KCalendarCore::Calendar::Ptr &cale
 KCALUTILS_EXPORT QString durationString(const KCalendarCore::Incidence::Ptr &incidence);
 
 class EventViewerVisitor;
-template<typename T> class ScheduleMessageVisitor;
+template<typename T>
+class ScheduleMessageVisitor;
 class InvitationHeaderVisitor;
 class InvitationBodyVisitor;
 class ToolTipVisitor;
 class MailBodyVisitor;
 }
 }
-
-#endif
